==> dqops-0.2.0.5-py2.py3-none-any.whl: dqops/client/models/column_strings_string_match_regex_percent_sensor_parameters_spec.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="ColumnStringsStringMatchRegexPercentSensorParametersSpec")


@attr.s(auto_attribs=True)
class ColumnStringsStringMatchRegexPercentSensorParametersSpec:
    """
    Attributes:
        filter_ (Union[Unset, str]): SQL WHERE clause added to the sensor query. Both the table level filter and a
            sensor query filter are added, separated by an AND operator.
        regex (Union[Unset, str]): This field can be used to define custom regex. In order to define custom regex, user
            should write correct regex as a string. If regex is not defined by user then default regex is null
    """

    filter_: Union[Unset, str] = UNSET
    regex: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        filter_ = self.filter_
        regex = self.regex

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if filter_ is not UNSET:
            field_dict["filter"] = filter_
        if regex is not UNSET:
            field_dict["regex"] = regex

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        filter_ = d.pop("filter", UNSET)

        regex = d.pop("regex", UNSET)

        column_strings_string_match_regex_percent_sensor_parameters_spec = cls(
            filter_=filter_,
            regex=regex,
        )

        column_strings_string_match_regex_percent_sensor_parameters_spec.additional_properties = (
            d
        )
        return column_strings_string_match_regex_percent_sensor_parameters_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> dqops-0.3.0-py2.py3-none-any.whl: dqops/client/models/column_strings_string_match_regex_percent_sensor_parameters_spec.py <==
from typing import Any, Dict, List, Type, TypeVar, Union

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

T = TypeVar("T", bound="ColumnStringsStringMatchRegexPercentSensorParametersSpec")


@_attrs_define
class ColumnStringsStringMatchRegexPercentSensorParametersSpec:
    """
    Attributes:
        filter_ (Union[Unset, str]): SQL WHERE clause added to the sensor query. Both the table level filter and a
            sensor query filter are added, separated by an AND operator.
        regex (Union[Unset, str]): This field can be used to define custom regex. In order to define custom regex, user
            should write correct regex as a string. If regex is not defined by user then default regex is null
    """

    filter_: Union[Unset, str] = UNSET
    regex: Union[Unset, str] = UNSET
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        filter_ = self.filter_
        regex = self.regex

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if filter_ is not UNSET:
            field_dict["filter"] = filter_
        if regex is not UNSET:
            field_dict["regex"] = regex

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        filter_ = d.pop("filter", UNSET)

        regex = d.pop("regex", UNSET)

        column_strings_string_match_regex_percent_sensor_parameters_spec = cls(
            filter_=filter_,
            regex=regex,
        )

        column_strings_string_match_regex_percent_sensor_parameters_spec.additional_properties = (
            d
        )
        return column_strings_string_match_regex_percent_sensor_parameters_spec

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
